Installation
============

Installing django-bulk-tracker is simple and straightforward. First of all, you need a copy of ``django-bulk-tracker`` on your system. The easiest
way to do this is by using the Python Package Index (PyPI). Simply run the following command:

``pip install django-bulk-tracker``

Instead of installing ``django-bulk-tracker`` via PyPI, you can also clone the Git repository or download the source code via GitHub.
The repository can be found at https://github.com/hassaanalansary/django-bulk-tracker/.

**Requirements**

- Python 3.9 or higher
- Django 3.2 or higher

``django-bulk-tracker`` is currently tested with Python 3.9+ and Django 3.2 and 4.0+.

Adding django-bulk-tracker to your Django application
-----------------------------------------------------

To use django-bulk-tracker in your application, just add ``'bulk-tracker'`` to your project's ``INSTALLED_APPS`` ``settings.py``
